/*
  +----------------------------------------------------------------------+
  | PHP Version 4                                                        |
  +----------------------------------------------------------------------+
  | Copyright (c) 1997-2003 The PHP Group                                |
  +----------------------------------------------------------------------+
  | This source file is subject to version 2.02 of the PHP license,      |
  | that is bundled with this package in the file LICENSE, and is        |
  | available at through the world-wide-web at                           |
  | http://www.php.net/license/2_02.txt.                                 |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Author: Karsten Dambekalns <k.dambekalns@fishfarm.de>                |
  +----------------------------------------------------------------------+

  $Id: wbxml.c,v 1.1.1.1 2003/12/01 16:02:18 karsten Exp $ 
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "php.h"
#include "php_ini.h"
#include "ext/standard/info.h"
#include "php_wbxml.h"

#include "wbxml.h"

/* If you declare any globals in php_wbxml.h uncomment this:
ZEND_DECLARE_MODULE_GLOBALS(wbxml)
*/

/* True global resources - no need for thread safety here */
static int le_wbxml;

/* {{{ wbxml_functions[]
 *
 * Every user visible function must have an entry in wbxml_functions[].
 */
function_entry wbxml_functions[] = {
	PHP_FE(wbxml2xml,	NULL)
	PHP_FE(xml2wbxml,	NULL)
	{NULL, NULL, NULL}	/* Must be the last line in wbxml_functions[] */
};
/* }}} */

/* {{{ wbxml_module_entry
 */
zend_module_entry wbxml_module_entry = {
#if ZEND_MODULE_API_NO >= 20010901
	STANDARD_MODULE_HEADER,
#endif
	"wbxml",
	wbxml_functions,
	PHP_MINIT(wbxml),
	PHP_MSHUTDOWN(wbxml),
	NULL,
	NULL,
	PHP_MINFO(wbxml),
#if ZEND_MODULE_API_NO >= 20010901
	"0.1", /* Replace with version number for your extension */
#endif
	STANDARD_MODULE_PROPERTIES
};
/* }}} */

#ifdef COMPILE_DL_WBXML
ZEND_GET_MODULE(wbxml)
#endif

/* {{{ PHP_MINIT_FUNCTION
 */
PHP_MINIT_FUNCTION(wbxml)
{
	/* If you have INI entries, uncomment these lines 
	ZEND_INIT_MODULE_GLOBALS(wbxml, php_wbxml_init_globals, NULL);
	REGISTER_INI_ENTRIES();
	*/
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MSHUTDOWN_FUNCTION
 */
PHP_MSHUTDOWN_FUNCTION(wbxml)
{
	/* uncomment this line if you have INI entries
	UNREGISTER_INI_ENTRIES();
	*/
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MINFO_FUNCTION
 */
PHP_MINFO_FUNCTION(wbxml)
{
	php_info_print_table_start();
	php_info_print_table_row(2, "wbxml support", "enabled");
	php_info_print_table_row(2, "RCS version", "$Id: wbxml.c,v 1.1.1.1 2003/12/01 16:02:18 karsten Exp $");
	php_info_print_table_end();
}
/* }}} */

/* {{{ proto string wbxml2xml(string arg)
   Return XML from WBXML string */
PHP_FUNCTION(wbxml2xml)
{
    WB_UTINY *wbxml = NULL, *xml = NULL;
    WB_LONG wbxml_size = 0, total = 0;
    WBXMLError ret = WBXML_OK;
    WBXMLConvWBXML2XMLParams params;

	if ((ZEND_NUM_ARGS() != 1) || (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &wbxml, &wbxml_size) == FAILURE)) {
		WRONG_PARAM_COUNT;
	}

	/* Init Default Parameters */    
    params.lang = WBXML_LANG_UNKNOWN;
    params.gen_type = WBXML_ENCODER_XML_GEN_INDENT;
    params.indent = 1;
    params.keep_ignorable_ws = FALSE;

	/* Convert WBXML document */
	ret = wbxml_conv_wbxml2xml(wbxml, wbxml_size, &xml, &params);
	if (ret != WBXML_OK) {
		zend_error(E_WARNING, "wbxml2xml conversion failed (%s)", wbxml_errors_string(ret));
	}
	else {
		RETVAL_STRINGL(xml, strlen(xml), 1);
	}

	/* Clean-up */
 	wbxml_free(xml);
}
/* }}} */

/* {{{ proto string xml2wbxml(string arg)
   Return a WBXML string from XML */
PHP_FUNCTION(xml2wbxml)
{
    WB_UTINY *wbxml = NULL, *xml = NULL;
    WB_LONG wbxml_size = 0, xml_size = 0;
    WBXMLError ret = WBXML_OK;
    WBXMLConvXML2WBXMLParams params;

	if ((ZEND_NUM_ARGS() != 1) || (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &xml, &xml_size) == FAILURE)) {
		WRONG_PARAM_COUNT;
	}

	/* Init Default Parameters */    
    params.wbxml_version = WBXML_VERSION_13;
    params.use_strtbl = TRUE;
    params.keep_ignorable_ws = FALSE;

	/* Convert WBXML document */
	ret = wbxml_conv_xml2wbxml(xml, &wbxml, &wbxml_size, &params);
	if (ret != WBXML_OK) {
		zend_error(E_WARNING, "xml2wbxml conversion failed (%s)", wbxml_errors_string(ret));
	}
	else {
		RETVAL_STRINGL(wbxml, wbxml_size, 1);
	}

	/* Clean-up */
 	wbxml_free(wbxml);
}
/* }}} */


/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */
